"""default values for the command line interface
"""

# RELHUM not yet available
variables = ["T", "FI", "U", "V", "QD", "QW"]
plevs = [100, 200, 500, 850, 950]
